Package 'netknitr'

Title: Knit Network Map for any Dataset
Description: Designed to create interactive and visually compelling network maps using R Shiny. It allows users to quickly analyze CSV files and visualize complex relationships, structures, and connections within data by leveraging powerful network analysis libraries and dynamic web interfaces.
Authors: Jayachandra N [aut, cre], Pushker Ravindra [aut]
Maintainer: Jayachandra N <[email protected]>
License: GPL-3
Version: 0.2.1
Built: 2026-06-10 07:38:22 UTC
Source: https://github.com/cran/netknitr

Help Index


createVisNetwork

Description

Generates network map using the nodes and edges objects generated by getNodes and getEdges functions respectively.

Usage

createVisNetwork(
  nodes,
  edges,
  background = "lightblue",
  border = "darkblue",
  highlight = "yellow"
)

Arguments

nodes

Nodes.

edges

Edges.

background

Background color.

border

Border color.

highlight

Highlight color.

Value

Network map visualization

Author(s)

Jayachandra N

Examples

nodes <- getNodes(head(mtcars), c("cyl", "gear", "vs"), group = TRUE)
res <- fixNodeBias(head(mtcars))
edges <- getEdges(getAssociation(res), getNodes(res, group = TRUE))
createVisNetwork(nodes, edges)

fixNodeBias

Description

Fix the possible bias that occurs while generating the nodes.

Usage

fixNodeBias(my_data)

Arguments

my_data

data frame

Value

data frame

Author(s)

Jayachandra N

Examples

res <- fixNodeBias(head(mtcars))

getAssociation

Description

Determine the associations between the values of different columns within the input data frame crude_data.

Usage

getAssociation(crude_data)

Arguments

crude_data

data frame to get associations between the values of different columns

Value

data frame of edges indicating from and to nodes

Author(s)

Jayachandra N

Examples

getAssociation(head(mtcars))

getEdges

Description

Generate edges or lines data frame which defines the link between nodes.

Usage

getEdges(polished_data, nodes)

Arguments

polished_data

data frame, output of getAssociation function

nodes

data frame, output of getNodes function

Value

data frame of edges indicationg from and to node ids

Author(s)

Jayachandra N

Examples

res <- fixNodeBias(head(mtcars))
edges <- getEdges(getAssociation(res), getNodes(res, group = TRUE))

getNodes

Description

Generate nodes for the input data frame, returns data frame of possible nodes and its IDs for the further process.

Usage

getNodes(crude_data, columns_for_nodes = NULL, group = FALSE)

Arguments

crude_data

Data Frame that you want to build a network for.

columns_for_nodes

Vector of column names for crude_data, works well for at least 3 columns

group

Logical value, set TRUE to differentiate nodes by shapes and colors. Default value is FALSE

Value

Data frame, each unique item is a node and associated with unique id

Author(s)

Jayachandra N

Examples

getNodes(head(mtcars), c("cyl", "gear", "vs"), group = TRUE)

getShapes

Description

Generate shapes for the given nodes, shapes can be defined using the shapes otherwise defaults to null.

Usage

getShapes(nodes, shapes = NULL)

Arguments

nodes

nodes data, output of getNodes function

shapes

character vector indicating manual shapes to choose for nodes

Value

a vector of shapes which is ready to cbind with nodes data

Author(s)

Jayachandra N

Examples

nodes <- getNodes(head(mtcars), c("cyl", "gear", "vs"), group =TRUE)
nodes$shape <- getShapes(nodes)

knitNet

Description

Run inbuilt R shiny app.

Usage

knitNet()

Value

shiny ui page

Author(s)

Jayachandra N

Examples

knitNet()

readMyFile

Description

Read input files including .csv, .xlsx and .txt files in tabular format and return as data.frame.

Usage

readMyFile(this_file)

Arguments

this_file

File path

Value

data.frame, content of the file.

Author(s)

Jayachandra N

Examples

temp_file <- tempfile(fileext = ".csv")
write.csv(mtcars, temp_file)
readMyFile(temp_file)